@@ -24,19 +24,20 @@ import typer
 try:
     from centralcli import (cli, cliadd, clibatch, clicaas, cliclone, clidel,
                             clirefresh, clishow, clitest, cliupdate,
-                            cliupgrade, config, log, utils)
+                            cliupgrade, clitshoot, config, log, utils)
 except (ImportError, ModuleNotFoundError) as e:
     pkg_dir = Path(__file__).absolute().parent
     if pkg_dir.name == "centralcli":
         sys.path.insert(0, str(pkg_dir.parent))
         from centralcli import (cli, cliadd, clibatch, clicaas, cliclone,
                                 clidel, clirefresh, clishow, clitest,
-                                cliupdate, cliupgrade, config, log, utils)
+                                cliupdate, cliupgrade, clitshoot, config, log, utils)
     else:
         print(pkg_dir.parts)
         raise e
 
 from centralcli.central import CentralApi  # noqa
+from centralcli.cache import CentralObject
 from centralcli.constants import (
     BlinkArgs, BounceArgs, IdenMetaVars,
     KickArgs, LicenseTypes, RenameArgs, StartArgs
@@ -51,7 +52,6 @@ CONTEXT_SETTINGS = {
 
 app = typer.Typer(context_settings=CONTEXT_SETTINGS)
 app.add_typer(clishow.app, name="show",)
-# app.add_typer(clido.app, name="do",)
 app.add_typer(clidel.app, name="delete")
 app.add_typer(cliadd.app, name="add",)
 app.add_typer(cliclone.app, name="clone",)
@@ -61,6 +61,7 @@ app.add_typer(clibatch.app, name="batch",)
 app.add_typer(clicaas.app, name="caas", hidden=True,)
 app.add_typer(clirefresh.app, name="refresh",)
 app.add_typer(clitest.app, name="test",)
+app.add_typer(clitshoot.app, name="tshoot",)
 
 
 class MoveArgs(str, Enum):
@@ -269,7 +270,7 @@ def bounce(
         raise typer.Abort()
 
 
-@app.command(short_help="Remove a device from a site.", help="Remove a device from a site.")
+@app.command(help="Remove a device from a site")
 def remove(
     devices: List[str] = typer.Argument(..., metavar=iden.dev_many, autocompletion=cli.cache.remove_completion),
     # _device: List[str] = typer.Argument(..., metavar=iden.dev, autocompletion=cli.cache.completion),
@@ -318,10 +319,45 @@ def remove(
 
 # TODO Add test
 # FIXME can unhide once adapt to query device inventory / devices not checked into central yet.
-@app.command(short_help="Assign License to device(s).", help="Assign License to device(s)", hidden=True)
+@app.command(short_help="Assign License to device(s)", hidden=False)
 def assign(
     license: LicenseTypes = typer.Argument(..., help="License type to apply to device(s)."),
-    devices: List[str] = typer.Argument(..., metavar=iden.dev_many,),
+    serial_nums: List[str] = typer.Argument(...,),
+    yes: bool = typer.Option(False, "-Y", help="Bypass confirmation prompts - Assume Yes"),
+    yes_: bool = typer.Option(False, "-y", hidden=True),
+    debug: bool = typer.Option(False, "--debug", envvar="ARUBACLI_DEBUG", help="Enable Additional Debug Logging",),
+    default: bool = typer.Option(False, "-d", is_flag=True, help="Use default central account", show_default=False,),
+    account: str = typer.Option("central_info",
+                                envvar="ARUBACLI_ACCOUNT",
+                                help="The Aruba Central Account to use (must be defined in the config)",
+                                autocompletion=cli.cache.account_completion),
+) -> None:
+    """Assign Licenses to devices by serial number.
+
+    Device must already be added to Central.  Use 'cencli show inventory' to see devices that have been added.
+    Use '--license' option with 'cencli add device ...' to add device and assign license in one command.
+    """
+    yes = yes_ if yes_ else yes
+    # devices = [cli.cache.get_dev_identifier(dev) for dev in devices]
+
+    # TODO add confirmation method builder to output class
+    _msg = f"Assign [bright_green]{license}[/bright_green] to"
+    if len(serial_nums) > 1:
+        _dev_msg = '\n    '.join([f'[cyan]{dev}[/]' for dev in serial_nums])
+        _msg = f"{_msg}:\n{_dev_msg}"
+    else:
+        dev = serial_nums[0]
+        _msg = f"{_msg} [cyan]{dev}[/]"
+    print(_msg)
+    if yes or typer.confirm("\nProceed?"):
+        resp = cli.central.request(cli.central.assign_licenses, serial_nums, services=license.name)
+        cli.display_results(resp, tablefmt="action")
+
+
+@app.command(help="unassign License from device(s)")
+def unassign(
+    license: LicenseTypes = typer.Argument(..., help="License type to unassign from device(s)."),
+    devices: List[str] = typer.Argument(..., metavar=iden.dev_many, autocompletion=cli.cache.dev_completion),
     yes: bool = typer.Option(False, "-Y", help="Bypass confirmation prompts - Assume Yes"),
     yes_: bool = typer.Option(False, "-y", hidden=True),
     debug: bool = typer.Option(False, "--debug", envvar="ARUBACLI_DEBUG", help="Enable Additional Debug Logging",),
@@ -332,19 +368,36 @@ def assign(
                                 autocompletion=cli.cache.account_completion),
 ) -> None:
     yes = yes_ if yes_ else yes
-    # devices = [cli.cache.get_dev_identifier(dev) for dev in devices]
+    try:
+        devices: CentralObject = [cli.cache.get_dev_identifier(dev) for dev in devices]
+    except typer.Exit:  # allows un-assignment of devices that never checked into Central
+        print("[bright_green]Checking full Inventory[/]")
+        inv = cli.central.request(cli.central.get_device_inventory)
+        serials_in_inventory = [i.get("serial", "ERROR") for i in inv.output]
+        class Device:
+            def __init__(self, serial):
+                self.serial = serial
+                self.summary_text = f"Device with serial {serial}"
+        dev_out = []
+        for dev in devices:
+            if dev.upper() not in serials_in_inventory:
+                print(f"{dev} not found in inventory.")
+                raise typer.Exit(1)
+            else:
+                dev_out += [Device(dev)]
+        devices = dev_out
 
-    # TODO add confirmation method builder to output class
-    _msg = f"Assign [bright_green]{license}[/bright_green] to"
+    _msg = f"Unassign [bright_green]{license}[/bright_green] from"
     if len(devices) > 1:
-        _dev_msg = '\n    '.join([f'[cyan]{dev.name}|{dev.serial}|{dev.mac}[/]' for dev in devices])
-        _msg = f"{_msg}:\n{_dev_msg}"
+        _dev_msg = '\n    '.join([dev.summary_text for dev in devices])
+        _msg = f"{_msg}:\n    {_dev_msg}"
     else:
         dev = devices[0]
-        _msg = f"{_msg} [cyan]{dev.name}|{dev.serial}|{dev.mac}[/]"
+        _msg = f"{_msg} {dev.summary_text}"
     print(_msg)
+
     if yes or typer.confirm("\nProceed?"):
-        resp = cli.central.request(cli.central.assign_licenses, [d.serial for d in devices], services=license)
+        resp = cli.central.request(cli.central.unassign_licenses, [d.serial for d in devices], services=license.name)
         cli.display_results(resp, tablefmt="action")
 
 
@@ -450,7 +503,7 @@ def sync(
 
 # XXX Doesn't actually appear to be valid for any group rename
 # TODO non batch rename AP
-@app.command(short_help="Rename an Access Point.", help="Rename an Access Point", hidden=False)
+@app.command(help="Rename an Access Point", hidden=False)
 def rename(
     what: RenameArgs = typer.Argument(...,),
     group_ap: str = typer.Argument(..., metavar=f"AP{iden.dev}", autocompletion=cli.cache.dev_kwarg_completion),
@@ -610,7 +663,7 @@ def start(
             print(f"[{p.pid}] WebHook Proxy Started.")
 
 
-@app.command(short_help="Start WebHook Proxy", hidden=not hook_enabled)
+@app.command(short_help="Stop WebHook Proxy", hidden=not hook_enabled)
 def stop(
     what: StartArgs = typer.Argument(
         ...,
@@ -625,10 +678,7 @@ def stop(
                                 help="The Aruba Central Account to use (must be defined in the config)",
                                 autocompletion=cli.cache.account_completion),
 ) -> None:
-    """Start WebHook Proxy Service on this system in the background
-
-    Requires optional hook-proxy component 'pip3 install centralcli[hook-proxy]'
-
+    """Stop WebHook Proxy (background process).
     """
     yes = yes_ if yes_ else yes
     def terminate_process(pid):
