@@ -2,10 +2,11 @@
 # -*- coding: utf-8 -*-
 
 import asyncio
+import json
 import sys
 from enum import Enum
 from pathlib import Path
-from typing import List, Literal
+from typing import List, Tuple
 import typer
 from pydantic import BaseModel, Extra, Field, ValidationError, validator
 from rich.console import Console
@@ -23,7 +24,7 @@ except (ImportError, ModuleNotFoundError) as e:
         print(pkg_dir.parts)
         raise e
 
-from centralcli.constants import GatewayRole, GenericDevIdens, IdenMetaVars, SendConfigDevIdens, SiteStates, state_abbrev_to_pretty
+from centralcli.constants import BatchAddArgs, BatchRenameArgs, GatewayRole, AllDevTypes, IdenMetaVars, SendConfigDevIdens, SiteStates, state_abbrev_to_pretty
 
 iden_meta_vars = IdenMetaVars()
 tty = utils.tty
@@ -31,7 +32,7 @@ app = typer.Typer()
 
 class GroupImport(BaseModel):
     group: str
-    allowed_types: List[GenericDevIdens] = Field(["ap", "gw", "cx", "sw"], alias="types")
+    allowed_types: List[AllDevTypes] = Field(["ap", "gw", "cx", "sw"], alias="types")
     gw_role: GatewayRole = Field("branch", alias="gw-role")
     aos10: bool = False
     microbranch: bool = False
@@ -70,14 +71,6 @@ class SiteImport(BaseModel):
             return SiteStates(v).value
 
 
-
-
-class BatchArgs(str, Enum):
-    sites = "sites"
-    # aps = "aps"
-    groups = "groups"
-
-
 class BatchDelArgs(str, Enum):
     sites = "sites"
     # aps = "aps"
@@ -453,6 +446,22 @@ class PreConfig(BaseModel):
     class Config:
         arbitrary_types_allowed = True
 
+# TODO finish extraction of uplink commands from commands sent to gw
+# so they can be sent in 2nd request as gw always errors interface doesn't
+# exist yet.
+def _extract_uplink_commands(commands: List[str]) -> Tuple[List[str], List[str]]:
+    _start=None
+    uplk_cmds = []
+    for idx, c in enumerate(commands):
+        if c.lower().startswith("uplink wired"):
+            _start = idx
+        elif _start and c.lstrip().startswith("!"):
+            uplk_cmds += [slice(_start, idx + 1)]
+            _start = None
+    uplk_lines = [line for x in [commands[s] for s in uplk_cmds] for line in x]
+    idx_list = [x for idx in [list(range(s.start, s.stop)) for s in uplk_cmds] for x in idx]
+    non_uplk_lines = [cmd for idx, cmd in enumerate(commands) if idx not in idx_list]
+    return uplk_lines, non_uplk_lines
 
 def _build_pre_config(node: str, dev_type: SendConfigDevIdens, cfg_file: Path, var_file: Path = None) -> PreConfig:
     """Build Configuration from raw config or jinja2 template/variable file.
@@ -582,15 +591,39 @@ def batch_add_groups(import_file: Path, yes: bool = False) -> List[Response]:
             cli.display_results(resp,  tablefmt="action")
 
 
+def batch_add_devices(import_file: Path, yes: bool = False) -> List[Response]:
+    console = Console(emoji=False)
+    br = cli.central.BatchRequest
+    data = config.get_file_data(import_file)
+    # TODO Import object class with consistent return.  Accept pydantic model as param
+    #      for validation...
+    pass
+    if hasattr(data, "headers"):
+        _reqd_cols = ["serial", "mac"]
+        for c in _reqd_cols:
+            if c not in data.headers:
+                print(f"[reset]::warning::[bright_red] !![/]Missing Required column header [cyan]{c}[/]")
+                print(f"\n.csv file is required to have the following headers:")
+                print("[cyan]serial[/], [cyan]mac[/]")
+                print(f"\nThe following headers/columns are optional:")
+                print("[cyan]group[/], [cyan]license[reset]")
+                # TODO finish full deploy workflow with config per-ap-settings variables etc allowed
+                raise typer.Exit(1)
+        data = json.loads(data.json)
+    # TODO Verify yaml/json/csv should now all look the same... only tested with csv
+    resp = cli.central.request(cli.central.add_devices, device_list=data)
+    return resp
+
 
 @app.command(short_help="Perform Batch Add from file")
 def add(
-    what: BatchArgs = typer.Argument(...,),
+    what: BatchAddArgs = typer.Argument(...,),
     import_file: Path = typer.Argument(..., exists=True),
     yes: bool = typer.Option(False, "-Y", help="Bypass confirmation prompts - Assume Yes"),
     yes_: bool = typer.Option(False, "-y", hidden=True),
     default: bool = typer.Option(
-        False, "-d", is_flag=True, help="Use default central account", show_default=False
+        False, "-d", is_flag=True, help="Use default central account", show_default=False,
+        callback=cli.default_callback,
     ),
     debug: bool = typer.Option(
         False, "--debug", envvar="ARUBACLI_DEBUG", help="Enable Additional Debug Logging",
@@ -608,6 +641,9 @@ def add(
         cli.display_results(resp)
     elif what == "groups":
         batch_add_groups(import_file, yes)
+    elif what == "devices":
+        resp = batch_add_devices(import_file, yes)
+        cli.display_results(resp, tablefmt="action")
 
 
 @app.command()
@@ -689,7 +725,7 @@ def delete(
 
 @app.command(help="Batch rename APs based on import file or site/LLDP info.")
 def rename(
-    what: BatchArgs = typer.Argument(...,),
+    what: BatchRenameArgs = typer.Argument(...,),
     import_file: Path = typer.Argument(None, metavar="['lldp'|IMPORT FILE PATH]"),  # TODO completion
     lldp: bool = typer.Option(None, help="Automatic AP rename based on lldp info from upstream switch.",),
     ap: str = typer.Option(None, metavar=iden_meta_vars.dev, help="[LLDP rename] Perform on specified AP",),
