@@ -398,7 +398,7 @@ class CLICommon:
                 where the result is a simple success/error.
             title: (str, optional): Title of output table.
                 Only applies to "rich" tablefmt. Defaults to None.
-            caption: (str, optional): Caption displayed at bottome of table.
+            caption: (str, optional): Caption displayed at bottom of table.
                 Only applies to "rich" tablefmt. Defaults to None.
             pager (bool, optional): Page Output / or not. Defaults to True.
             outfile (Path, optional): path/file of output file. Defaults to None.
@@ -450,12 +450,16 @@ class CLICommon:
 
                 if self.raw_out:
                     tablefmt = "raw"
+
+                # if not r.output:
+                #     c = Console(record=True)
+                #     c.begin_capture()
+                #     c.print(f"  Status Code: [{fg}]{r.status}[/]")
+                #     c.print(f"  :warning: Empty Response.  This may be normal.")
+                #     r.output = c.end_capture()
                 if not r.output:
-                    c = Console(record=True)
-                    c.begin_capture()
-                    c.print(f"  Status Code: [{fg}]{r.status}[/]")
-                    c.print(f"  :warning: Empty Response.  This may be normal.")
-                    r.output = c.end_capture()
+                    print(f"  Status Code: [{fg}]{r.status}[/]")
+                    print(f"  :warning: Empty Response.  This may be normal.")
 
                 if not r or tablefmt in ["action", "raw"]:
 
