@@ -23,7 +23,7 @@ except (ImportError, ModuleNotFoundError) as e:
         print(pkg_dir.parts)
         raise e
 
-from centralcli.constants import IdenMetaVars, TemplateDevIdens, GatewayRole
+from centralcli.constants import IdenMetaVars, DevTypes, GatewayRole
 from centralcli import CentralObject
 
 
@@ -57,7 +57,7 @@ def template(
         help="The template group the template belongs to",
         autocompletion=cli.cache.group_completion
     ),
-    device_type: TemplateDevIdens = typer.Option(
+    device_type: DevTypes = typer.Option(
         None, "--dev-type",
         help="Filter by Device Type",
     ),
@@ -247,12 +247,6 @@ def group(
         allowed_types += ["cx"]
     if gw:
         allowed_types += ["gw"]
-    if not all(x is None for x in [ap, sw, cx, gw]):
-        ...
-        # resp = cli.central.request(
-        #     cli.central.get_groups_properties,
-        #     group.name
-        # )
 
     _msg = f"[cyan]Update [cyan]group [bright_green]{group.name}[/bright_green]"
     if aos10 is not None:
@@ -283,7 +277,6 @@ def group(
         "gw_role": gw_role,
         "monitor_only_sw": mo_sw,
     }
-    # kwargs = utils.strip_none(kwargs)
 
     if yes or typer.confirm("Proceed with values?"):
         resp = cli.central.request(
@@ -292,54 +285,6 @@ def group(
         )
         cli.display_results(resp, tablefmt="action")
 
-# TODO command for update site
-
-@app.command(
-    short_help="Update group properties",
-    help="Update group properties (AOS8 vs AOS10 & Monitor Only Switch enabled/disabled)",
-    hidden=True,
-    deprecated=True,
-)
-def group_old(
-    group_name: str = typer.Argument(..., autocompletion=cli.cache.group_completion),
-    aos_version: int = typer.Argument(None, metavar="[10]", help="Set to 10 to Upgrade group to AOS 10"),
-    mos: bool = typer.Option(None, help="Enable monitor only for switches in the group"),
-    yes: bool = typer.Option(False, "-Y", help="Bypass confirmation prompts - Assume Yes"),
-    yes_: bool = typer.Option(False, "-y", hidden=True),
-    update_cache: bool = typer.Option(False, "-U", hidden=True),  # Force Update of cli.cache for testing
-    debug: bool = typer.Option(False, "--debug", envvar="ARUBACLI_DEBUG", help="Enable Additional Debug Logging",),
-    default: bool = typer.Option(False, "-d", is_flag=True, help="Use default central account", show_default=False,),
-    account: str = typer.Option("central_info",
-                                envvar="ARUBACLI_ACCOUNT",
-                                help="The Aruba Central Account to use (must be defined in the config)",),
-) -> None:
-    yes = yes_ if yes_ else yes
-    cli.cache(refresh=update_cache)
-    group = cli.cache.get_group_identifier(group_name)
-
-    _msg = [
-        typer.style("Update group", fg="cyan"),
-        typer.style(group.name, fg="bright_green"),
-    ]
-    if aos_version:
-        _msg += [
-            typer.style("AOS version", fg="cyan"),
-            typer.style(str(aos_version), fg="bright_green"),
-            typer.style("[Note: AOS10 groups can not be downgraded back to AOS8]", fg="red"),
-        ]
-
-    _msg = " ".join(_msg)
-
-    if mos is not None:
-        _msg = f'{_msg}{", " if aos_version else ": "}{typer.style("monitor only switch", fg="cyan")}'
-        _msg = f'{_msg} {typer.style("enabled" if mos else "disabled", fg="bright_green")}'
-
-    _msg = f'{_msg}{typer.style("?", fg="cyan")}'
-
-    if yes or typer.confirm(_msg, abort=True):
-        resp = cli.central.request(cli.central.update_group_properties_v1, group.name, aos_version, monitor_only_switch=mos)
-        cli.display_results(resp)
-
 def generate_template(template_file: Union[Path, str], var_file: Union[Path, str], group_dev: str):
     '''Generate configuration files based on j2 templates and provided variables
     '''
