@@ -10,7 +10,7 @@ lib_dev_idens = ["ap", "cx", "sw", "switch", "gw"]
 LibDevIdens = Literal["ap", "cx", "sw", "switch", "gw"]
 
 
-class GenericDevIdens(str, Enum):
+class AllDevTypes(str, Enum):
     ap = "ap"
     sw = "sw"
     cx = "cx"
@@ -18,7 +18,13 @@ class GenericDevIdens(str, Enum):
     switch = "switch"
 
 
-class TemplateDevIdens(str, Enum):
+class GenericDevTypes(str, Enum):
+    ap = "ap"
+    gw = "gw"
+    switch = "switch"
+
+
+class DevTypes(str, Enum):
     ap = "ap"
     sw = "sw"
     cx = "cx"
@@ -32,12 +38,54 @@ class SendConfigDevIdens(str, Enum):
     # cx = "cx"
 
 
+class ShowInventoryArgs(str, Enum):
+    all = "all"
+    ap = "ap"
+    gw = "gw"
+    vgw = "vgw"
+    switch = "switch"
+    others = "others"
+
+
+SHOWINVENTORY_LIB_TO_API = {
+    "all": "all",
+    "ap": "all_ap",
+    "switch": "switch",
+    "gw": "gateway",
+    "vgw": "vgw",
+    "others": "others"
+}
+
+class InventorySortOptions(str, Enum):
+    type = "type"
+    model = "model"
+    sku = "sku"
+    mac = "mac"
+    serial = "serial"
+    services = "services"
+
 class GatewayRole(str, Enum):
     branch = "branch"
     vpnc = "vpnc"
     wlan = "wlan"
 
 
+class CertTypes(str, Enum):
+    SERVER_CERT = "SERVER_CERT"
+    CA_CERT = "CA_CERT"
+    CRL = "CRL"
+    INTERMEDIATE_CA = "INTERMEDIATE_CA"
+    OCSP_RESPONDER_CERT = "OCSP_RESPONDER_CERT"
+    OCSP_SIGNER_CERT = "OCSP_SIGNER_CERT"
+    PUBLIC_CERT = "PUBLIC_CERT"
+
+
+class CertFormat(str, Enum):
+    PEM = "PEM"
+    DER = "DER"
+    PKCS12 = "PKCS12"
+
+
 class StartArgs(str, Enum):
     hook_proxy = "hook-proxy"
 
@@ -48,7 +96,7 @@ STRIP_KEYS = [
     "gateways",
     "switches",
     "aps",
-    "swarms"
+    "swarms",
     "devices",
     "mcs",
     "group",
@@ -68,6 +116,7 @@ STRIP_KEYS = [
     "notifications",
     "settings",
     "items",
+    "poe_details",
 ]
 
 
@@ -185,6 +234,15 @@ class KickArgs(str, Enum):
 class BatchApArgs(str, Enum):
     rename = "rename"
 
+class BatchAddArgs(str, Enum):
+    sites = "sites"
+    groups = "groups"
+    devices = "devices"
+
+class BatchRenameArgs(str, Enum):
+    sites = "sites"
+    aps = "aps"
+    groups = "groups"
 
 class RenameArgs(str, Enum):
     group = "group"
@@ -206,6 +264,7 @@ class LicenseTypes(str, Enum):
     advanced_switch_6200 = "advanced-switch-6200"
     advanced_switch_6300 = "advanced-switch-6300"
     advanced_switch_6400 = "advanced-switch-6400"
+    advanced_switch_8400 = "advanced-switch-8400"
     dm = "dm"
     foundation_70xx = "foundation-70xx"
     foundation_72xx = "foundation-72xx"
@@ -217,6 +276,7 @@ class LicenseTypes(str, Enum):
     foundation_switch_6200 = "foundation-switch-6200"
     foundation_switch_6300 = "foundation-switch-6300"
     foundation_switch_6400 = "foundation-switch-6400"
+    foundation_switch_8400 = "foundation-switch-8400"
     foundation_wlan_gw = "foundation-wlan-gw"
     vgw2g = "vgw2g"
     vgw4g = "vgw4g"
@@ -254,6 +314,10 @@ class ArgToWhat:
         self.run = self.running = "run"
         self.routes = self.route = "routes"
         self.webhooks = self.webhook = "webhooks"
+        self.token = self.tokens = "token"
+
+    def _init_refresh(self):
+        self.token = self.tokens = "token"
 
     def _init_update(self):
         self.template = self.templates = "template"
